# coding: utf-8

"""
NVIDIA Run:ai

# Introduction  The NVIDIA Run:ai Control-Plane API reference is a guide that provides an easy-to-use programming interface for adding various tasks to your application, including workload submission, resource management, and administrative operations.  NVIDIA Run:ai APIs are accessed using *bearer tokens*. To obtain a token, you need to create an **Application** through the NVIDIA Run:ai user interface. To create an application, in your UI, go to `Settings & Tools`, `Application` and create a new Application.  After you have created a new application, you will need to assign it access rules. To assign access rules to the application, see [Create access rules](https://run-ai-docs.nvidia.com/saas/infrastructure-setup/authentication/accessrules#create-or-delete-rules). Make sure you assign the correct rules to your application. Use the [Roles](https://run-ai-docs.nvidia.com/saas/infrastructure-setup/authentication/roles) to assign the correct access rules.  To get your access token, follow the instructions in [Request a token](https://run-ai-docs.nvidia.com/saas/reference/api/rest-auth/#request-an-api-token).

The version of the OpenAPI document: latest
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self


class ClusterDependencyStatus(BaseModel):
    """
    Pydantic class model representing ClusterDependencyStatus.

    Parameters:
        ```python
        available: bool
        reason: str
        components: Dict[str, ClusterDependencyStatus]
        ```
        available: whether the dependency is available
        reason: the reason for the dependency status
        components: See model Dict[str, ClusterDependencyStatus] for more information.
    Example:
        ```python
        ClusterDependencyStatus(
            available=True,
                        reason='',
                        components={
                    'key' : runai.models.cluster_dependency_status.ClusterDependencyStatus(
                        available = True,
                        reason = '',
                        components = {
                            'key' : runai.models.cluster_dependency_status.ClusterDependencyStatus(
                                available = True,
                                reason = '', )
                            }, )
                    }
        )
        ```
    """  # noqa: E501

    available: StrictBool = Field(description="whether the dependency is available")
    reason: Optional[StrictStr] = Field(
        default=None, description="the reason for the dependency status"
    )
    components: Optional[Dict[str, ClusterDependencyStatus]] = None
    __properties: ClassVar[List[str]] = ["available", "reason", "components"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ClusterDependencyStatus from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each value in components (dict)
        _field_dict = {}
        if self.components:
            for _key_components in self.components:
                if self.components[_key_components]:
                    _field_dict[_key_components] = self.components[
                        _key_components
                    ].to_dict()
            _dict["components"] = _field_dict
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ClusterDependencyStatus from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "available": obj.get("available"),
                "reason": obj.get("reason"),
                "components": (
                    dict(
                        (_k, ClusterDependencyStatus.from_dict(_v))
                        for _k, _v in obj["components"].items()
                    )
                    if obj.get("components") is not None
                    else None
                ),
            }
        )
        return _obj


# TODO: Rewrite to not use raise_errors
ClusterDependencyStatus.model_rebuild(raise_errors=False)
