# coding: utf-8

"""
NVIDIA Run:ai

# Introduction  The NVIDIA Run:ai Control-Plane API reference is a guide that provides an easy-to-use programming interface for adding various tasks to your application, including workload submission, resource management, and administrative operations.  NVIDIA Run:ai APIs are accessed using *bearer tokens*. To obtain a token, you need to create an **Application** through the NVIDIA Run:ai user interface. To create an application, in your UI, go to `Settings & Tools`, `Application` and create a new Application.  After you have created a new application, you will need to assign it access rules. To assign access rules to the application, see [Create access rules](https://run-ai-docs.nvidia.com/saas/infrastructure-setup/authentication/accessrules#create-or-delete-rules). Make sure you assign the correct rules to your application. Use the [Roles](https://run-ai-docs.nvidia.com/saas/infrastructure-setup/authentication/roles) to assign the correct access rules.  To get your access token, follow the instructions in [Request a token](https://run-ai-docs.nvidia.com/saas/reference/api/rest-auth/#request-an-api-token).

The version of the OpenAPI document: latest
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field
from typing import Any, ClassVar, Dict, List, Optional
from runai.models.string_rules import StringRules
from typing import Optional, Set
from typing_extensions import Self


class ConfigMapRules(BaseModel):
    """
    Pydantic class model representing ConfigMapRules.

    Parameters:
        ```python
        config_map: Optional[StringRules]
        mount_path: Optional[StringRules]
        sub_path: Optional[StringRules]
        ```
        config_map: See model StringRules for more information.
        mount_path: See model StringRules for more information.
        sub_path: See model StringRules for more information.
    Example:
        ```python
        ConfigMapRules(
            config_map=runai.models.string_rules.StringRules(),
                        mount_path=runai.models.string_rules.StringRules(),
                        sub_path=runai.models.string_rules.StringRules()
        )
        ```
    """  # noqa: E501

    config_map: Optional[StringRules] = Field(default=None, alias="configMap")
    mount_path: Optional[StringRules] = Field(default=None, alias="mountPath")
    sub_path: Optional[StringRules] = Field(default=None, alias="subPath")
    __properties: ClassVar[List[str]] = ["configMap", "mountPath", "subPath"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ConfigMapRules from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of config_map
        if self.config_map:
            _dict["configMap"] = self.config_map.to_dict()
        # override the default output from pydantic by calling `to_dict()` of mount_path
        if self.mount_path:
            _dict["mountPath"] = self.mount_path.to_dict()
        # override the default output from pydantic by calling `to_dict()` of sub_path
        if self.sub_path:
            _dict["subPath"] = self.sub_path.to_dict()
        # set to None if config_map (nullable) is None
        # and model_fields_set contains the field
        if self.config_map is None and "config_map" in self.model_fields_set:
            _dict["configMap"] = None

        # set to None if mount_path (nullable) is None
        # and model_fields_set contains the field
        if self.mount_path is None and "mount_path" in self.model_fields_set:
            _dict["mountPath"] = None

        # set to None if sub_path (nullable) is None
        # and model_fields_set contains the field
        if self.sub_path is None and "sub_path" in self.model_fields_set:
            _dict["subPath"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ConfigMapRules from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "configMap": (
                    StringRules.from_dict(obj["configMap"])
                    if obj.get("configMap") is not None
                    else None
                ),
                "mountPath": (
                    StringRules.from_dict(obj["mountPath"])
                    if obj.get("mountPath") is not None
                    else None
                ),
                "subPath": (
                    StringRules.from_dict(obj["subPath"])
                    if obj.get("subPath") is not None
                    else None
                ),
            }
        )
        return _obj
