# coding: utf-8

"""
NVIDIA Run:ai

# Introduction  The NVIDIA Run:ai Control-Plane API reference is a guide that provides an easy-to-use programming interface for adding various tasks to your application, including workload submission, resource management, and administrative operations.  NVIDIA Run:ai APIs are accessed using *bearer tokens*. To obtain a token, you need to create an **Application** through the NVIDIA Run:ai user interface. To create an application, in your UI, go to `Settings & Tools`, `Application` and create a new Application.  After you have created a new application, you will need to assign it access rules. To assign access rules to the application, see [Create access rules](https://run-ai-docs.nvidia.com/saas/infrastructure-setup/authentication/accessrules#create-or-delete-rules). Make sure you assign the correct rules to your application. Use the [Roles](https://run-ai-docs.nvidia.com/saas/infrastructure-setup/authentication/roles) to assign the correct access rules.  To get your access token, follow the instructions in [Request a token](https://run-ai-docs.nvidia.com/saas/reference/api/rest-auth/#request-an-api-token).

The version of the OpenAPI document: latest
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field
from typing import Any, ClassVar, Dict, List, Optional
from runai.models.department1_current import Department1Current
from runai.models.department1_metadata import Department1Metadata
from typing import Optional, Set
from typing_extensions import Self


class DepartmentsDataInner(BaseModel):
    """
    Pydantic class model representing DepartmentsDataInner.

    Parameters:
        ```python
        metadata: Department1Metadata
        current: Department1Current
        time_range: Optional[object]
        ```
        metadata: See model Department1Metadata for more information.
        current: See model Department1Current for more information.
        time_range: See model object for more information.
    Example:
        ```python
        DepartmentsDataInner(
            metadata=runai.models.department1_metadata.Department1_metadata(
                    department_id = 8,
                    department_name = 'default',
                    cluster_id = '71f69d83-ba66-4822-adf5-55ce55efd210',
                    cluster_name = 'cluster-a', ),
                        current=runai.models.department1_current.Department1_current(
                    resources = [
                        null
                        ],
                    project_resources = [
                        null
                        ], ),
                        time_range="example"
        )
        ```
    """  # noqa: E501

    metadata: Department1Metadata
    current: Department1Current
    time_range: Optional[Any] = Field(default=None, alias="timeRange")
    __properties: ClassVar[List[str]] = ["metadata", "current", "timeRange"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of DepartmentsDataInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of metadata
        if self.metadata:
            _dict["metadata"] = self.metadata.to_dict()
        # override the default output from pydantic by calling `to_dict()` of current
        if self.current:
            _dict["current"] = self.current.to_dict()
        # set to None if time_range (nullable) is None
        # and model_fields_set contains the field
        if self.time_range is None and "time_range" in self.model_fields_set:
            _dict["timeRange"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of DepartmentsDataInner from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "metadata": (
                    Department1Metadata.from_dict(obj["metadata"])
                    if obj.get("metadata") is not None
                    else None
                ),
                "current": (
                    Department1Current.from_dict(obj["current"])
                    if obj.get("current") is not None
                    else None
                ),
                "timeRange": obj.get("timeRange"),
            }
        )
        return _obj
