# coding: utf-8

"""
NVIDIA Run:ai

# Introduction  The NVIDIA Run:ai Control-Plane API reference is a guide that provides an easy-to-use programming interface for adding various tasks to your application, including workload submission, resource management, and administrative operations.  NVIDIA Run:ai APIs are accessed using *bearer tokens*. To obtain a token, you need to create an **Application** through the NVIDIA Run:ai user interface. To create an application, in your UI, go to `Settings & Tools`, `Application` and create a new Application.  After you have created a new application, you will need to assign it access rules. To assign access rules to the application, see [Create access rules](https://run-ai-docs.nvidia.com/saas/infrastructure-setup/authentication/accessrules#create-or-delete-rules). Make sure you assign the correct rules to your application. Use the [Roles](https://run-ai-docs.nvidia.com/saas/infrastructure-setup/authentication/roles) to assign the correct access rules.  To get your access token, follow the instructions in [Request a token](https://run-ai-docs.nvidia.com/saas/reference/api/rest-auth/#request-an-api-token).

The version of the OpenAPI document: latest
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool
from typing import Any, ClassVar, Dict, List, Optional
from runai.models.distributed_spec_spec import DistributedSpecSpec
from runai.models.master_spec import MasterSpec
from runai.models.runnable_info import RunnableInfo
from runai.models.template_master_section import TemplateMasterSection
from runai.models.template_meta_fields import TemplateMetaFields
from typing import Optional, Set
from typing_extensions import Self


class DistributedTemplate(BaseModel):
    """
    Pydantic class model representing DistributedTemplate.

    Parameters:
        ```python
        meta: TemplateMetaFields
        spec: DistributedSpecSpec
        master_spec_same_as_worker: Optional[bool]
        master: Optional[TemplateMasterSection]
        runnable: RunnableInfo
        combined_spec: DistributedSpecSpec
        combined_master_spec: Optional[MasterSpec]
        ```
        meta: See model TemplateMetaFields for more information.
        spec: See model DistributedSpecSpec for more information.
        master_spec_same_as_worker: used for distributed workloads to indicate that the master spec should be the same as the worker spec. in this case, masterSpec should not be specified.
        master: See model TemplateMasterSection for more information.
        runnable: See model RunnableInfo for more information.
        combined_spec: See model DistributedSpecSpec for more information.
        combined_master_spec: See model MasterSpec for more information.
    Example:
        ```python
        DistributedTemplate(
            meta=runai.models.template_meta_fields.TemplateMetaFields(
                    id = '550e8400-e29b-41d4-a716-446655440000',
                    name = 'my-template-name',
                    description = 'description of my template.',
                    workload_type = 'Workspace',
                    scope_type = 'system',
                    scope_id = '',
                    cluster_id = '71f69d83-ba66-4822-adf5-55ce55efd210',
                    department_id = '2',
                    project_id = 1,
                    created_by = 'test@lab.com',
                    created_at = '2022-01-01T03:49:52.531Z',
                    updated_by = 'test@lab.com',
                    updated_at = '2022-01-01T03:49:52.531Z', ),
                        spec="example",
                        master_spec_same_as_worker=True,
                        master=runai.models.template_master_section.TemplateMasterSection(
                    spec = runai.models.master_spec.MasterSpec(),
                    assets = runai.models.assets.assets(), ),
                        runnable=runai.models.runnable_info.RunnableInfo(
                    is_runnable = False,
                    issue = 'mandatory image is not provided', ),
                        combined_spec="example",
                        combined_master_spec=runai.models.master_spec.MasterSpec()
        )
        ```
    """  # noqa: E501

    meta: TemplateMetaFields
    spec: Optional[DistributedSpecSpec] = None
    master_spec_same_as_worker: Optional[StrictBool] = Field(
        default=None,
        description="used for distributed workloads to indicate that the master spec should be the same as the worker spec. in this case, masterSpec should not be specified.",
        alias="masterSpecSameAsWorker",
    )
    master: Optional[TemplateMasterSection] = None
    runnable: Optional[RunnableInfo] = None
    combined_spec: Optional[DistributedSpecSpec] = Field(
        default=None, alias="combinedSpec"
    )
    combined_master_spec: Optional[MasterSpec] = Field(
        default=None, alias="combinedMasterSpec"
    )
    __properties: ClassVar[List[str]] = [
        "meta",
        "spec",
        "masterSpecSameAsWorker",
        "master",
        "runnable",
        "combinedSpec",
        "combinedMasterSpec",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of DistributedTemplate from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of meta
        if self.meta:
            _dict["meta"] = self.meta.to_dict()
        # override the default output from pydantic by calling `to_dict()` of spec
        if self.spec:
            _dict["spec"] = self.spec.to_dict()
        # override the default output from pydantic by calling `to_dict()` of master
        if self.master:
            _dict["master"] = self.master.to_dict()
        # override the default output from pydantic by calling `to_dict()` of runnable
        if self.runnable:
            _dict["runnable"] = self.runnable.to_dict()
        # override the default output from pydantic by calling `to_dict()` of combined_spec
        if self.combined_spec:
            _dict["combinedSpec"] = self.combined_spec.to_dict()
        # override the default output from pydantic by calling `to_dict()` of combined_master_spec
        if self.combined_master_spec:
            _dict["combinedMasterSpec"] = self.combined_master_spec.to_dict()
        # set to None if master_spec_same_as_worker (nullable) is None
        # and model_fields_set contains the field
        if (
            self.master_spec_same_as_worker is None
            and "master_spec_same_as_worker" in self.model_fields_set
        ):
            _dict["masterSpecSameAsWorker"] = None

        # set to None if master (nullable) is None
        # and model_fields_set contains the field
        if self.master is None and "master" in self.model_fields_set:
            _dict["master"] = None

        # set to None if combined_master_spec (nullable) is None
        # and model_fields_set contains the field
        if (
            self.combined_master_spec is None
            and "combined_master_spec" in self.model_fields_set
        ):
            _dict["combinedMasterSpec"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of DistributedTemplate from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "meta": (
                    TemplateMetaFields.from_dict(obj["meta"])
                    if obj.get("meta") is not None
                    else None
                ),
                "spec": (
                    DistributedSpecSpec.from_dict(obj["spec"])
                    if obj.get("spec") is not None
                    else None
                ),
                "masterSpecSameAsWorker": obj.get("masterSpecSameAsWorker"),
                "master": (
                    TemplateMasterSection.from_dict(obj["master"])
                    if obj.get("master") is not None
                    else None
                ),
                "runnable": (
                    RunnableInfo.from_dict(obj["runnable"])
                    if obj.get("runnable") is not None
                    else None
                ),
                "combinedSpec": (
                    DistributedSpecSpec.from_dict(obj["combinedSpec"])
                    if obj.get("combinedSpec") is not None
                    else None
                ),
                "combinedMasterSpec": (
                    MasterSpec.from_dict(obj["combinedMasterSpec"])
                    if obj.get("combinedMasterSpec") is not None
                    else None
                ),
            }
        )
        return _obj
