# coding: utf-8

"""
NVIDIA Run:ai

# Introduction  The NVIDIA Run:ai Control-Plane API reference is a guide that provides an easy-to-use programming interface for adding various tasks to your application, including workload submission, resource management, and administrative operations.  NVIDIA Run:ai APIs are accessed using *bearer tokens*. To obtain a token, you need to create an **Application** through the NVIDIA Run:ai user interface. To create an application, in your UI, go to `Settings & Tools`, `Application` and create a new Application.  After you have created a new application, you will need to assign it access rules. To assign access rules to the application, see [Create access rules](https://run-ai-docs.nvidia.com/saas/infrastructure-setup/authentication/accessrules#create-or-delete-rules). Make sure you assign the correct rules to your application. Use the [Roles](https://run-ai-docs.nvidia.com/saas/infrastructure-setup/authentication/roles) to assign the correct access rules.  To get your access token, follow the instructions in [Request a token](https://run-ai-docs.nvidia.com/saas/reference/api/rest-auth/#request-an-api-token).

The version of the OpenAPI document: latest
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List
from runai.models.node_info import NodeInfo
from typing import Optional, Set
from typing_extensions import Self


class NodeForSync(BaseModel):
    """
    Pydantic class model representing NodeForSync.

    Parameters:
        ```python
        name: str
        node_info: NodeInfo
        ```
        name: The name of the node
        node_info: See model NodeInfo for more information.
    Example:
        ```python
        NodeForSync(
            name='worker-node-1',
                        node_info=runai.models.node_info.NodeInfo(
                    status = 'Ready',
                    conditions = [
                        runai.models.node_status_condition_details.NodeStatusConditionDetails(
                            type = '',
                            reason = 'KubeletNotReady',
                            message = 'container runtime status check may not have completed yet', )
                        ],
                    taints = [
                        runai.models.node_taint.NodeTaint(
                            key = 'foo',
                            value = 'bar',
                            effect = 'NoSchedule', )
                        ],
                    node_pool = 'node-pool-1',
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                    gpu_info = runai.models.gpu_info.GpuInfo(
                        gpu_type = 'Tesla-V100',
                        gpu_count = 56, ),
                    nv_link_domain_uid = 'nvlink-domain-uid',
                    nv_link_clique_id = 'clique-id', )
        )
        ```
    """  # noqa: E501

    name: StrictStr = Field(description="The name of the node")
    node_info: NodeInfo = Field(alias="nodeInfo")
    __properties: ClassVar[List[str]] = ["name", "nodeInfo"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of NodeForSync from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of node_info
        if self.node_info:
            _dict["nodeInfo"] = self.node_info.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of NodeForSync from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "name": obj.get("name"),
                "nodeInfo": (
                    NodeInfo.from_dict(obj["nodeInfo"])
                    if obj.get("nodeInfo") is not None
                    else None
                ),
            }
        )
        return _obj
