# coding: utf-8

"""
NVIDIA Run:ai

# Introduction  The NVIDIA Run:ai Control-Plane API reference is a guide that provides an easy-to-use programming interface for adding various tasks to your application, including workload submission, resource management, and administrative operations.  NVIDIA Run:ai APIs are accessed using *bearer tokens*. To obtain a token, you need to create an **Application** through the NVIDIA Run:ai user interface. To create an application, in your UI, go to `Settings & Tools`, `Application` and create a new Application.  After you have created a new application, you will need to assign it access rules. To assign access rules to the application, see [Create access rules](https://run-ai-docs.nvidia.com/saas/infrastructure-setup/authentication/accessrules#create-or-delete-rules). Make sure you assign the correct rules to your application. Use the [Roles](https://run-ai-docs.nvidia.com/saas/infrastructure-setup/authentication/roles) to assign the correct access rules.  To get your access token, follow the instructions in [Request a token](https://run-ai-docs.nvidia.com/saas/reference/api/rest-auth/#request-an-api-token).

The version of the OpenAPI document: latest
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict
from typing import Any, ClassVar, Dict, List
from runai.models.permitted_scopes import PermittedScopes
from typing import Optional, Set
from typing_extensions import Self


class PermittedScopesActions(BaseModel):
    """
    Pydantic class model representing PermittedScopesActions.

    Parameters:
        ```python
        create: PermittedScopes
        read: PermittedScopes
        update: PermittedScopes
        delete: PermittedScopes
        ```
        create: See model PermittedScopes for more information.
        read: See model PermittedScopes for more information.
        update: See model PermittedScopes for more information.
        delete: See model PermittedScopes for more information.
    Example:
        ```python
        PermittedScopesActions(
            create=runai.models.permitted_scopes.PermittedScopes(
                    system = False,
                    tenants = [
                        '1'
                        ],
                    tenant = '1',
                    clusters = [
                        'a418ed33-9399-48c0-a890-122cadd13bfd'
                        ],
                    departments = [
                        '7'
                        ],
                    projects = [
                        ''
                        ], ),
                        read=runai.models.permitted_scopes.PermittedScopes(
                    system = False,
                    tenants = [
                        '1'
                        ],
                    tenant = '1',
                    clusters = [
                        'a418ed33-9399-48c0-a890-122cadd13bfd'
                        ],
                    departments = [
                        '7'
                        ],
                    projects = [
                        ''
                        ], ),
                        update=runai.models.permitted_scopes.PermittedScopes(
                    system = False,
                    tenants = [
                        '1'
                        ],
                    tenant = '1',
                    clusters = [
                        'a418ed33-9399-48c0-a890-122cadd13bfd'
                        ],
                    departments = [
                        '7'
                        ],
                    projects = [
                        ''
                        ], ),
                        delete=runai.models.permitted_scopes.PermittedScopes(
                    system = False,
                    tenants = [
                        '1'
                        ],
                    tenant = '1',
                    clusters = [
                        'a418ed33-9399-48c0-a890-122cadd13bfd'
                        ],
                    departments = [
                        '7'
                        ],
                    projects = [
                        ''
                        ], )
        )
        ```
    """  # noqa: E501

    create: PermittedScopes
    read: PermittedScopes
    update: PermittedScopes
    delete: PermittedScopes
    __properties: ClassVar[List[str]] = ["create", "read", "update", "delete"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PermittedScopesActions from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of create
        if self.create:
            _dict["create"] = self.create.to_dict()
        # override the default output from pydantic by calling `to_dict()` of read
        if self.read:
            _dict["read"] = self.read.to_dict()
        # override the default output from pydantic by calling `to_dict()` of update
        if self.update:
            _dict["update"] = self.update.to_dict()
        # override the default output from pydantic by calling `to_dict()` of delete
        if self.delete:
            _dict["delete"] = self.delete.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PermittedScopesActions from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "create": (
                    PermittedScopes.from_dict(obj["create"])
                    if obj.get("create") is not None
                    else None
                ),
                "read": (
                    PermittedScopes.from_dict(obj["read"])
                    if obj.get("read") is not None
                    else None
                ),
                "update": (
                    PermittedScopes.from_dict(obj["update"])
                    if obj.get("update") is not None
                    else None
                ),
                "delete": (
                    PermittedScopes.from_dict(obj["delete"])
                    if obj.get("delete") is not None
                    else None
                ),
            }
        )
        return _obj
