# coding: utf-8

"""
NVIDIA Run:ai

# Introduction  The NVIDIA Run:ai Control-Plane API reference is a guide that provides an easy-to-use programming interface for adding various tasks to your application, including workload submission, resource management, and administrative operations.  NVIDIA Run:ai APIs are accessed using *bearer tokens*. To obtain a token, you need to create an **Application** through the NVIDIA Run:ai user interface. To create an application, in your UI, go to `Settings & Tools`, `Application` and create a new Application.  After you have created a new application, you will need to assign it access rules. To assign access rules to the application, see [Create access rules](https://run-ai-docs.nvidia.com/saas/infrastructure-setup/authentication/accessrules#create-or-delete-rules). Make sure you assign the correct rules to your application. Use the [Roles](https://run-ai-docs.nvidia.com/saas/infrastructure-setup/authentication/roles) to assign the correct access rules.  To get your access token, follow the instructions in [Request a token](https://run-ai-docs.nvidia.com/saas/reference/api/rest-auth/#request-an-api-token).

The version of the OpenAPI document: latest
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictFloat, StrictInt
from typing import Any, ClassVar, Dict, List, Optional, Union
from runai.models.node_selector_term import NodeSelectorTerm
from typing import Optional, Set
from typing_extensions import Self


class PodPreferredNodeSelectorTerm(BaseModel):
    """
    Pydantic class model representing An empty preferred scheduling term matches all objects with implicit weight 0 (i.e. it's a no-op). A null preferred scheduling term matches no objects (i.e. is also a no-op)..

    Parameters:
        ```python
        weight: float
        preference: Optional[NodeSelectorTerm]
        ```
        weight: Weight associated with matching the corresponding nodeSelectorTerm, in the range 1-100.
        preference: See model NodeSelectorTerm for more information.
    Example:
        ```python
        PodPreferredNodeSelectorTerm(
            weight=1.337,
                        preference=runai.models.node_selector_term.NodeSelectorTerm(
                    match_expressions = [
                        runai.models.match_expression.MatchExpression(
                            key = '',
                            operator = 'In',
                            values = [
                                ''
                                ], )
                        ], )
        )
        ```
    """  # noqa: E501

    weight: Optional[Union[StrictFloat, StrictInt]] = Field(
        default=None,
        description="Weight associated with matching the corresponding nodeSelectorTerm, in the range 1-100.",
    )
    preference: Optional[NodeSelectorTerm] = None
    __properties: ClassVar[List[str]] = ["weight", "preference"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PodPreferredNodeSelectorTerm from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of preference
        if self.preference:
            _dict["preference"] = self.preference.to_dict()
        # set to None if preference (nullable) is None
        # and model_fields_set contains the field
        if self.preference is None and "preference" in self.model_fields_set:
            _dict["preference"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PodPreferredNodeSelectorTerm from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "weight": obj.get("weight"),
                "preference": (
                    NodeSelectorTerm.from_dict(obj["preference"])
                    if obj.get("preference") is not None
                    else None
                ),
            }
        )
        return _obj
