# coding: utf-8

"""
NVIDIA Run:ai

# Introduction  The NVIDIA Run:ai Control-Plane API reference is a guide that provides an easy-to-use programming interface for adding various tasks to your application, including workload submission, resource management, and administrative operations.  NVIDIA Run:ai APIs are accessed using *bearer tokens*. To obtain a token, you need to create an **Application** through the NVIDIA Run:ai user interface. To create an application, in your UI, go to `Settings & Tools`, `Application` and create a new Application.  After you have created a new application, you will need to assign it access rules. To assign access rules to the application, see [Create access rules](https://run-ai-docs.nvidia.com/saas/infrastructure-setup/authentication/accessrules#create-or-delete-rules). Make sure you assign the correct rules to your application. Use the [Roles](https://run-ai-docs.nvidia.com/saas/infrastructure-setup/authentication/roles) to assign the correct access rules.  To get your access token, follow the instructions in [Request a token](https://run-ai-docs.nvidia.com/saas/reference/api/rest-auth/#request-an-api-token).

The version of the OpenAPI document: latest
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict
from typing import Any, ClassVar, Dict, List, Optional
from runai.models.policy_sync_status_of_cluster import PolicySyncStatusOfCluster
from runai.models.policy_validation_status_validation import (
    PolicyValidationStatusValidation,
)
from typing import Optional, Set
from typing_extensions import Self


class PolicyListEntryStatus(BaseModel):
    """
    Pydantic class model representing PolicyListEntryStatus.

    Parameters:
        ```python
        clusters: List[PolicySyncStatusOfCluster]
        validation: Optional[PolicyValidationStatusValidation]
        ```
        clusters: See model List[PolicySyncStatusOfCluster] for more information.
        validation: See model PolicyValidationStatusValidation for more information.
    Example:
        ```python
        PolicyListEntryStatus(
            clusters=[
                    runai.models.policy_sync_status_of_cluster.PolicySyncStatusOfCluster(
                        cluster_id = '71f69d83-ba66-4822-adf5-55ce55efd210',
                        status = 'Not ready',
                        error_message = '', )
                    ],
                        validation=runai.models.policy_validation_status_validation.PolicyValidationStatus_validation(
                    error_message = '', )
        )
        ```
    """  # noqa: E501

    clusters: Optional[List[PolicySyncStatusOfCluster]] = None
    validation: Optional[PolicyValidationStatusValidation] = None
    __properties: ClassVar[List[str]] = ["clusters", "validation"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PolicyListEntryStatus from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in clusters (list)
        _items = []
        if self.clusters:
            for _item_clusters in self.clusters:
                if _item_clusters:
                    _items.append(_item_clusters.to_dict())
            _dict["clusters"] = _items
        # override the default output from pydantic by calling `to_dict()` of validation
        if self.validation:
            _dict["validation"] = self.validation.to_dict()
        # set to None if validation (nullable) is None
        # and model_fields_set contains the field
        if self.validation is None and "validation" in self.model_fields_set:
            _dict["validation"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PolicyListEntryStatus from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "clusters": (
                    [
                        PolicySyncStatusOfCluster.from_dict(_item)
                        for _item in obj["clusters"]
                    ]
                    if obj.get("clusters") is not None
                    else None
                ),
                "validation": (
                    PolicyValidationStatusValidation.from_dict(obj["validation"])
                    if obj.get("validation") is not None
                    else None
                ),
            }
        )
        return _obj
