# coding: utf-8

"""
NVIDIA Run:ai

# Introduction  The NVIDIA Run:ai Control-Plane API reference is a guide that provides an easy-to-use programming interface for adding various tasks to your application, including workload submission, resource management, and administrative operations.  NVIDIA Run:ai APIs are accessed using *bearer tokens*. To obtain a token, you need to create an **Application** through the NVIDIA Run:ai user interface. To create an application, in your UI, go to `Settings & Tools`, `Application` and create a new Application.  After you have created a new application, you will need to assign it access rules. To assign access rules to the application, see [Create access rules](https://run-ai-docs.nvidia.com/saas/infrastructure-setup/authentication/accessrules#create-or-delete-rules). Make sure you assign the correct rules to your application. Use the [Roles](https://run-ai-docs.nvidia.com/saas/infrastructure-setup/authentication/roles) to assign the correct access rules.  To get your access token, follow the instructions in [Request a token](https://run-ai-docs.nvidia.com/saas/reference/api/rest-auth/#request-an-api-token).

The version of the OpenAPI document: latest
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict
from typing import Any, ClassVar, Dict, List, Optional
from runai.models.project_v1_node_affinity_response_interactive import (
    ProjectV1NodeAffinityResponseInteractive,
)
from runai.models.project_v1_node_affinity_response_train import (
    ProjectV1NodeAffinityResponseTrain,
)
from typing import Optional, Set
from typing_extensions import Self


class ProjectV1NodeAffinityResponse(BaseModel):
    """
    Pydantic class model representing Node affinity configuration for jobs in the project..

    Parameters:
        ```python
        train: ProjectV1NodeAffinityResponseTrain
        interactive: ProjectV1NodeAffinityResponseInteractive
        ```
        train: See model ProjectV1NodeAffinityResponseTrain for more information.
        interactive: See model ProjectV1NodeAffinityResponseInteractive for more information.
    Example:
        ```python
        ProjectV1NodeAffinityResponse(
            train=runai.models.project_v1_node_affinity_response_train.ProjectV1NodeAffinityResponse_train(
                    affinity_type = 'no_limit',
                    selected_types = [
                        runai.models.project_v1_node_affinity_response_train_selected_types_inner.ProjectV1NodeAffinityResponse_train_selectedTypes_inner(
                            id = 1.337,
                            name = '', )
                        ], ),
                        interactive=runai.models.project_v1_node_affinity_response_interactive.ProjectV1NodeAffinityResponse_interactive(
                    affinity_type = 'no_limit',
                    selected_types = [
                        runai.models.project_v1_node_affinity_response_train_selected_types_inner.ProjectV1NodeAffinityResponse_train_selectedTypes_inner(
                            id = 1.337,
                            name = '', )
                        ], )
        )
        ```
    """  # noqa: E501

    train: Optional[ProjectV1NodeAffinityResponseTrain] = None
    interactive: Optional[ProjectV1NodeAffinityResponseInteractive] = None
    __properties: ClassVar[List[str]] = ["train", "interactive"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ProjectV1NodeAffinityResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of train
        if self.train:
            _dict["train"] = self.train.to_dict()
        # override the default output from pydantic by calling `to_dict()` of interactive
        if self.interactive:
            _dict["interactive"] = self.interactive.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ProjectV1NodeAffinityResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "train": (
                    ProjectV1NodeAffinityResponseTrain.from_dict(obj["train"])
                    if obj.get("train") is not None
                    else None
                ),
                "interactive": (
                    ProjectV1NodeAffinityResponseInteractive.from_dict(
                        obj["interactive"]
                    )
                    if obj.get("interactive") is not None
                    else None
                ),
            }
        )
        return _obj
