# coding: utf-8

"""
NVIDIA Run:ai

# Introduction  The NVIDIA Run:ai Control-Plane API reference is a guide that provides an easy-to-use programming interface for adding various tasks to your application, including workload submission, resource management, and administrative operations.  NVIDIA Run:ai APIs are accessed using *bearer tokens*. To obtain a token, you need to create an **Application** through the NVIDIA Run:ai user interface. To create an application, in your UI, go to `Settings & Tools`, `Application` and create a new Application.  After you have created a new application, you will need to assign it access rules. To assign access rules to the application, see [Create access rules](https://run-ai-docs.nvidia.com/saas/infrastructure-setup/authentication/accessrules#create-or-delete-rules). Make sure you assign the correct rules to your application. Use the [Roles](https://run-ai-docs.nvidia.com/saas/infrastructure-setup/authentication/roles) to assign the correct access rules.  To get your access token, follow the instructions in [Request a token](https://run-ai-docs.nvidia.com/saas/reference/api/rest-auth/#request-an-api-token).

The version of the OpenAPI document: latest
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field
from typing import Any, ClassVar, Dict, List, Optional
from runai.models.access_mode_customization import AccessModeCustomization
from runai.models.claim_size_customization import ClaimSizeCustomization
from runai.models.pvc_added_attribute import PvcAddedAttribute
from runai.models.volume_mode_customization import VolumeModeCustomization
from typing import Optional, Set
from typing_extensions import Self


class StorageClassCustomization(BaseModel):
    """
    Pydantic class model representing StorageClassCustomization.

    Parameters:
        ```python
        access_mode: Optional[AccessModeCustomization]
        volume_mode: Optional[VolumeModeCustomization]
        claim_size: Optional[ClaimSizeCustomization]
        attributes: List[PvcAddedAttribute]
        ```
        access_mode: See model AccessModeCustomization for more information.
        volume_mode: See model VolumeModeCustomization for more information.
        claim_size: See model ClaimSizeCustomization for more information.
        attributes: added attributes that needs to be populated to any PVC created under this storage class.
    Example:
        ```python
        StorageClassCustomization(
            access_mode=runai.models.access_mode_customization.AccessModeCustomization(
                    required = True,
                    default = runai.models.pvc_access_modes.PvcAccessModes(
                        read_write_once = True,
                        read_only_many = True,
                        read_write_many = True, ),
                    supported_values = runai.models.pvc_supported_access_modes.PvcSupportedAccessModes(
                        read_write_once = True,
                        read_only_many = True,
                        read_write_many = True, ), ),
                        volume_mode=runai.models.volume_mode_customization.VolumeModeCustomization(
                    required = True,
                    default = 'Filesystem',
                    supported_values = runai.models.volume_mode_customization_supported_values.VolumeModeCustomization_supportedValues(
                        filesystem = True,
                        block = True, ), ),
                        claim_size=runai.models.claim_size_customization.ClaimSizeCustomization(
                    default = '1G',
                    supported_units = [
                        'MB'
                        ],
                    min = '1G',
                    max = '1G',
                    step = '1G', ),
                        attributes=[
                    runai.models.pvc_added_attribute.PvcAddedAttribute(
                        key = 'dnsname',
                        format = 'text',
                        display = 'DNS Name',
                        description = 'The host name of the DNS',
                        placeholder = 'enter hostname or IP address',
                        required = True,
                        default_value = 'my.dns.com',
                        validation_regexp = '^[a-zA-Z0-9.-_]+$',
                        min_value = 100,
                        max_value = 200,
                        step = 5,
                        validation_error = 'Invalid URL', )
                    ]
        )
        ```
    """  # noqa: E501

    access_mode: Optional[AccessModeCustomization] = Field(
        default=None, alias="accessMode"
    )
    volume_mode: Optional[VolumeModeCustomization] = Field(
        default=None, alias="volumeMode"
    )
    claim_size: Optional[ClaimSizeCustomization] = Field(
        default=None, alias="claimSize"
    )
    attributes: Optional[List[Optional[PvcAddedAttribute]]] = Field(
        default=None,
        description="added attributes that needs to be populated to any PVC created under this storage class.",
    )
    __properties: ClassVar[List[str]] = [
        "accessMode",
        "volumeMode",
        "claimSize",
        "attributes",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of StorageClassCustomization from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of access_mode
        if self.access_mode:
            _dict["accessMode"] = self.access_mode.to_dict()
        # override the default output from pydantic by calling `to_dict()` of volume_mode
        if self.volume_mode:
            _dict["volumeMode"] = self.volume_mode.to_dict()
        # override the default output from pydantic by calling `to_dict()` of claim_size
        if self.claim_size:
            _dict["claimSize"] = self.claim_size.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in attributes (list)
        _items = []
        if self.attributes:
            for _item_attributes in self.attributes:
                if _item_attributes:
                    _items.append(_item_attributes.to_dict())
            _dict["attributes"] = _items
        # set to None if access_mode (nullable) is None
        # and model_fields_set contains the field
        if self.access_mode is None and "access_mode" in self.model_fields_set:
            _dict["accessMode"] = None

        # set to None if volume_mode (nullable) is None
        # and model_fields_set contains the field
        if self.volume_mode is None and "volume_mode" in self.model_fields_set:
            _dict["volumeMode"] = None

        # set to None if claim_size (nullable) is None
        # and model_fields_set contains the field
        if self.claim_size is None and "claim_size" in self.model_fields_set:
            _dict["claimSize"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of StorageClassCustomization from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "accessMode": (
                    AccessModeCustomization.from_dict(obj["accessMode"])
                    if obj.get("accessMode") is not None
                    else None
                ),
                "volumeMode": (
                    VolumeModeCustomization.from_dict(obj["volumeMode"])
                    if obj.get("volumeMode") is not None
                    else None
                ),
                "claimSize": (
                    ClaimSizeCustomization.from_dict(obj["claimSize"])
                    if obj.get("claimSize") is not None
                    else None
                ),
                "attributes": (
                    [PvcAddedAttribute.from_dict(_item) for _item in obj["attributes"]]
                    if obj.get("attributes") is not None
                    else None
                ),
            }
        )
        return _obj
