# coding: utf-8

"""
NVIDIA Run:ai

# Introduction  The NVIDIA Run:ai Control-Plane API reference is a guide that provides an easy-to-use programming interface for adding various tasks to your application, including workload submission, resource management, and administrative operations.  NVIDIA Run:ai APIs are accessed using *bearer tokens*. To obtain a token, you need to create an **Application** through the NVIDIA Run:ai user interface. To create an application, in your UI, go to `Settings & Tools`, `Application` and create a new Application.  After you have created a new application, you will need to assign it access rules. To assign access rules to the application, see [Create access rules](https://run-ai-docs.nvidia.com/saas/infrastructure-setup/authentication/accessrules#create-or-delete-rules). Make sure you assign the correct rules to your application. Use the [Roles](https://run-ai-docs.nvidia.com/saas/infrastructure-setup/authentication/roles) to assign the correct access rules.  To get your access token, follow the instructions in [Request a token](https://run-ai-docs.nvidia.com/saas/reference/api/rest-auth/#request-an-api-token).

The version of the OpenAPI document: latest
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self


class WorkloadTypeConfig(BaseModel):
    """
    Pydantic class model representing WorkloadTypeConfig.

    Parameters:
        ```python
        id: str
        category_name: str
        priority_name: str
        updated_at: datetime
        updated_by: str
        ```
        id: The unique identifier of the workload type.
        category_name: The name of the workload category.
        priority_name: The name of the workload priority.
        updated_at: The time at which the type has been updated
        updated_by: The recent user who updated the type
    Example:
        ```python
        WorkloadTypeConfig(
            id='',
                        category_name='Build',
                        priority_name='medium',
                        updated_at=datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                        updated_by=''
        )
        ```
    """  # noqa: E501

    id: Optional[StrictStr] = Field(
        default=None, description="The unique identifier of the workload type."
    )
    category_name: Optional[StrictStr] = Field(
        default=None,
        description="The name of the workload category.",
        alias="categoryName",
    )
    priority_name: Optional[StrictStr] = Field(
        default=None,
        description="The name of the workload priority.",
        alias="priorityName",
    )
    updated_at: Optional[datetime] = Field(
        default=None,
        description="The time at which the type has been updated",
        alias="updatedAt",
    )
    updated_by: Optional[StrictStr] = Field(
        default=None,
        description="The recent user who updated the type",
        alias="updatedBy",
    )
    __properties: ClassVar[List[str]] = [
        "id",
        "categoryName",
        "priorityName",
        "updatedAt",
        "updatedBy",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of WorkloadTypeConfig from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of WorkloadTypeConfig from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "id": obj.get("id"),
                "categoryName": obj.get("categoryName"),
                "priorityName": obj.get("priorityName"),
                "updatedAt": obj.get("updatedAt"),
                "updatedBy": obj.get("updatedBy"),
            }
        )
        return _obj
